Snake class

Constructors

Snake(Point head)

Properties

hashCode → int
The hash code for this object.
no setterinherited
no setter
points → Set<Point>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tail → Point
no setter

Methods

draw() → void
drawDead(Direction dir) → void
drawKing() → void
grow() → void
isCollidingWithPoint(Point point) → bool
isCollidingWithPoints(Set<Point> otherPoints) → bool
move(Direction dir, {required Set<Point> walls}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited